@@ -31,8 +31,6 @@ class DataApi:
             'fields': fields
         }
 
-        print(req_params)
-
         res = requests.post(self.__http_url, json=req_params, timeout=self.__timeout)
         if res:
             result = json.loads(res.text)
@@ -41,9 +39,9 @@ class DataApi:
             data = result['data']
             columns = data['fields']
             items = data['items']
-            return pd.DataFrame(items, columns=columns)
+            return pd.DataFrame(items, columns=columns), data['total']
         else:
-            return pd.DataFrame()
+            return pd.DataFrame(), -1
 
     def __getattr__(self, name):
         return partial(self.query, name)
